@@ -84,7 +84,7 @@
 #define PURPOSEWIDGETS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef PURPOSEWIDGETS_NO_DEPRECATED
-#  define PURPOSEWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56a00
+#  define PURPOSEWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56b00
 #endif
 #ifdef PURPOSEWIDGETS_NO_DEPRECATED_WARNINGS
 #  define PURPOSEWIDGETS_DEPRECATED_WARNINGS_SINCE 0
@@ -94,7 +94,7 @@
 #  ifdef PURPOSEWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define PURPOSEWIDGETS_DEPRECATED_WARNINGS_SINCE PURPOSEWIDGETS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define PURPOSEWIDGETS_DEPRECATED_WARNINGS_SINCE 0x56a00
+#    define PURPOSEWIDGETS_DEPRECATED_WARNINGS_SINCE 0x56b00
 #  endif
 #endif
 
